@@ -1,4 +1,5 @@
-static void slirp_debug_pause(char *module_name)
+
+static void slirp_debug_pause(char *module_name) /* {{{ */
 {
    const char *var = getenv("SLIRP_DEBUG_PAUSE");
    if (var == NULL)
@@ -27,4 +28,5 @@ static void slirp_debug_pause(char *module_name)
    fprintf(stderr,"\n%s press any key in this window to continue\n",prefix);
    length = getchar();
  }
-}
+} /* }}} */
+
