@@ -6,7 +6,6 @@
 #define		KSINK_BAZ	"baz"
 #define		DECL(t)		extern t	/* tests macro handling */
 
-
 typedef struct { char *name; double value; } KDatum;
 typedef struct { double p[3]; unsigned long id; } KParams;
 struct KDummy { int i; float f; };
@@ -50,7 +49,6 @@ DECL(void)		ksink_ignorable_func	(void);
 DECL(void)		dummy1			(void);
 DECL(void)		dummy2			(void);
 DECL(void)		dummy3			(void);
-DECL(void)		dummy4			(void);
 
 DECL(VoidStar)	ksink_voidstar_echo	(VoidStar input);
 DECL(void)		ksink_arg_dropper_1	(unsigned long int ul);
@@ -78,3 +76,4 @@ extern  int		ksink_dummy_ok(struct KDummy* s);
 extern	int		KSINK_IGNORABLE_INT;
 extern	int		KSINK_IGNORABLE_INT2;
 #define			KSINK_IGNORABLE_MACRO2	110
+typedef struct _ks_struct ks_struct;	/* ignore: this exercises type system */
