@@ -64,3 +64,36 @@ int func4(double arr[3], unsigned int len);
 	#endif
   #endif
 #endif
+
+#define MAKE_DOUBLE 1
+#if defined(MAKE_DOUBLE) || defined(DOUBLE)
+typedef double RealType1;
+#else
+typedef float RealType1;
+#endif
+
+RealType1 real_func1(void);
+
+#undef MAKE_DOUBLE
+#ifdef MAKE_DOUBLE
+typedef double RealType2;
+#else
+typedef float RealType2;
+#endif
+
+RealType2 real_func2(void);
+
+/* This tests parsing of continued lines */
+#if (defined(MACRO3) && !defined(MAKE_DOUBLE)) ||  \
+(defined(MACRO1) && defined(MACRO2))
+RealType1 real_func3(void);
+#endif
+
+typedef float blah;
+
+#if (!defined(MAKE_DOUBLE) && \
+		!defined(MACRO3)) ||  \
+	(!defined(MACRO2) && \
+					!defined(MACRO1))
+RealType1 real_func4(void);	/* this should not be wrapped */
+#endif
