@@ -538,9 +538,7 @@ static SLang_Marshaller* slang_function_pop(unsigned int num_args_to_omit)
 static int usg_err(int expected_nargs, const char *usage_str)
 {
    if (SLang_Num_Function_Args < expected_nargs) {
-	char msg[257];
-	snprintf(msg,248,"Usage: %s",usage_str);
-	SLang_verror(SL_USAGE_ERROR,msg);
+	SLang_verror (SL_USAGE_ERROR, "Usage: %s", usage_str);
 	return -1;
    }
    return 0;
@@ -666,7 +664,7 @@ static void handler_passthru_wrapper(void)
    SLang_free_slstring(pt_pattern);
 }
 
-static void activate()
+static void activate(void)
 {
    Previous_Load_File_Hook = SLang_Load_File_Hook;
    Previous_Load_File_Ns_Hook = SLns_Load_File_Hook;
@@ -674,7 +672,7 @@ static void activate()
    SLang_Load_File_Hook = load_file;
 }
 
-static void deactivate()
+static void deactivate(void)
 {
    Handler_Entry *e, *n = Handler_Entries_Head;
 
@@ -688,7 +686,7 @@ static void deactivate()
    SLns_Load_File_Hook = Previous_Load_File_Ns_Hook;
 }
 
-static void allow_unterminated()
+static void allow_unterminated(void)
 {
    if (Current != NULL)			  /* support single-line blocks for  */
 	Current->flags |= ALLOW_UNTERM;	  /* tokens otherwise requiring #end */
